@@ -1,6 +1,6 @@
 from __future__ import print_function
+
 from extruct.tool import main
 
-
-if __name__ == '__main__':
+if __name__ == "__main__":
     print(main())
