@@ -1,3 +1,4 @@
+# mypy: disallow_untyped_defs=False
 # -*- coding: utf-8 -*-
 """
 JSON-LD extractor
@@ -11,11 +12,13 @@ import lxml.etree
 
 from extruct.utils import parse_html
 
-HTML_OR_JS_COMMENTLINE = re.compile(r'^\s*(//.*|<!--.*-->)')
+HTML_OR_JS_COMMENTLINE = re.compile(r"^\s*(//.*|<!--.*-->)")
 
 
-class JsonLdExtractor(object):
-    _xp_jsonld = lxml.etree.XPath('descendant-or-self::script[@type="application/ld+json"]')
+class JsonLdExtractor:
+    _xp_jsonld = lxml.etree.XPath(
+        'descendant-or-self::script[@type="application/ld+json"]'
+    )
 
     def extract(self, htmlstring, base_url=None, encoding="UTF-8"):
         tree = parse_html(htmlstring, encoding=encoding)
@@ -24,18 +27,20 @@ class JsonLdExtractor(object):
     def extract_items(self, document, base_url=None):
         return [
             item
-            for items in map(self._extract_items, self._xp_jsonld(document))
-            if items for item in items if item
+            for items in map(self._extract_items, self._xp_jsonld(document))  # type: ignore[arg-type]
+            if items
+            for item in items
+            if item
         ]
 
     def _extract_items(self, node):
-        script = node.xpath('string()')
+        script = node.xpath("string()")
         try:
             # TODO: `strict=False` can be configurable if needed
             data = json.loads(script, strict=False)
         except ValueError:
             # sometimes JSON-decoding errors are due to leading HTML or JavaScript comments
-            data = jstyleson.loads(HTML_OR_JS_COMMENTLINE.sub('', script), strict=False)
+            data = jstyleson.loads(HTML_OR_JS_COMMENTLINE.sub("", script), strict=False)
         if isinstance(data, list):
             for item in data:
                 yield item
