@@ -1,5 +1,9 @@
+# mypy: disallow_untyped_defs=False
 import copy
-from six.moves.urllib.parse import urlparse, urljoin
+from typing import Any
+
+from six.moves.urllib.parse import urljoin, urlparse
+
 from extruct.dublincore import get_lower_attrib
 
 
@@ -7,8 +11,8 @@ def _uopengraph(extracted, with_og_array=False):
     out = []
     for obj in extracted:
         # In order of appearance in the page
-        properties = list(obj['properties'])
-        flattened = {}
+        properties = list(obj["properties"])
+        flattened: dict[Any, Any] = {}
 
         for k, v in properties:
             if k not in flattened.keys():
@@ -26,10 +30,10 @@ def _uopengraph(extracted, with_og_array=False):
                     else:
                         flattened[k] = v
 
-        t = flattened.pop('og:type', None)
+        t = flattened.pop("og:type", None)
         if t:
-            flattened['@type'] = t
-        flattened['@context'] = obj['namespace']
+            flattened["@type"] = t
+        flattened["@context"] = obj["namespace"]
         out.append(flattened)
     return out
 
@@ -48,14 +52,14 @@ def _udublincore(extracted):
     out = []
     extracted_cpy = copy.deepcopy(extracted)
     for obj in extracted_cpy:
-        context = obj.pop('namespaces', None)
-        obj['@context'] = context
-        elements = obj['elements']
+        context = obj.pop("namespaces", None)
+        obj["@context"] = context
+        elements = obj["elements"]
         for element in elements:
             for key, value in element.items():
-                if get_lower_attrib(value) == 'type':
-                    obj['@type'] = element['content']
-                    obj['elements'].remove(element)
+                if get_lower_attrib(value) == "type":
+                    obj["@type"] = element["content"]
+                    obj["elements"].remove(element)
                     break
         out.append(obj)
     return out
@@ -66,8 +70,7 @@ def _flatten(element, schema_context):
         element = flatten_dict(element, schema_context, False)
     elif isinstance(element, list):
         element = [
-            flatten_dict(o, schema_context, False)
-            if isinstance(o, dict) else o
+            flatten_dict(o, schema_context, False) if isinstance(o, dict) else o
             for o in element
         ]
     return element
@@ -75,42 +78,42 @@ def _flatten(element, schema_context):
 
 def flatten_dict(d, schema_context, add_context):
     out = dict(d)
-    typ = out.pop('type', None)
+    typ = out.pop("type", None)
     if not typ:
         return d
 
     if isinstance(typ, list):
-        out['@type'] = typ
+        out["@type"] = typ
         context = schema_context
     else:
         context, typ = infer_context(typ, schema_context)
-        out['@type'] = typ
+        out["@type"] = typ
 
     if add_context:
-        out['@context'] = context
+        out["@context"] = context
 
-    props = out.pop('properties', {})
+    props = out.pop("properties", {})
     for field, value in props.items():
         value = _flatten(value, schema_context)
         out[field] = value
 
-    children = out.pop('children', [])
+    children = out.pop("children", [])
     if children:
-        out['children'] = []
+        out["children"] = []
     for child in children:
         child = _flatten(child, schema_context)
-        out['children'].append(child)
+        out["children"].append(child)
     return out
 
 
-def infer_context(typ, context='http://schema.org'):
+def infer_context(typ, context="http://schema.org"):
     parsed_context = urlparse(typ)
     if parsed_context.netloc:
-        base = ''.join([parsed_context.scheme, '://', parsed_context.netloc])
+        base = "".join([parsed_context.scheme, "://", parsed_context.netloc])
         if parsed_context.path and parsed_context.fragment:
             context = urljoin(base, parsed_context.path)
-            typ = parsed_context.fragment.strip('/')
+            typ = parsed_context.fragment.strip("/")
         elif parsed_context.path:
             context = base
-            typ = parsed_context.path.strip('/')
+            typ = parsed_context.path.strip("/")
     return context, typ
