@@ -1,3 +1,4 @@
+# mypy: disallow_untyped_defs=False
 # -*- coding: utf-8 -*-
 import json
 import unittest
@@ -11,8 +12,10 @@ class TestDublincore(unittest.TestCase):
     maxDiff = None
 
     def test_dublincore(self):
-        body = get_testdata('misc', 'dublincore_test.html')
-        expected = json.loads(get_testdata('misc', 'dublincore_test.json').decode('UTF-8'))
+        body = get_testdata("misc", "dublincore_test.html")
+        expected = json.loads(
+            get_testdata("misc", "dublincore_test.json").decode("UTF-8")
+        )
 
         dublincorext = DublinCoreExtractor()
         data = dublincorext.extract(body)
